unit MainUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls;

type
  TMainForm = class(TForm)
    Panel1: TPanel;
    GoButton: TButton;
    StopButton: TButton;
    DataList: TListBox;
    PollTime: TTimer;
    procedure FormCreate(Sender: TObject);
    procedure GoButtonClick(Sender: TObject);
    procedure StopButtonClick(Sender: TObject);
    procedure PollTimeTimer(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

uses
  AIOWDM;

var
  CardNum: LongWord;
  JumperData: Byte;
  Channels: Integer;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  CardNum := 0;
  if QueryCardInfo(CardNum, nil, nil, nil, nil) = 0 then begin
    GoButton.Enabled := False;
    StopButton.Enabled := False;
    DataList.Items.Text := 'No card found via AIOWDM.';
    Exit;
  end;
end;
 
procedure TMainForm.StopButtonClick(Sender: TObject);
begin
  PollTime.Enabled := False;
end;

procedure TMainForm.GoButtonClick(Sender: TObject);
begin
  RelOutPortB(CardNum, $1B, 0); // reset card

  JumperData := RelInPortB(CardNum, $12);
  if (JumperData and $02) <> 0 then
    Channels := 16
  else
    Channels := 8
  ;

  RelOutPort(CardNum, $2, $0000);                     // configure channel gains (ch 0-7)
  RelOutPort(CardNum, $4, $0000);                     // configure channel gains (ch 8-15)
  RelOutPortB(CardNum, $6, $10 * (Channels - 1));     // configure start->end scan range
  RelOutPortB(CardNum, $7, $0);                       // configure 0 oversamples
  // configure counter timers here, if you'll be using CTR timed conversions
  //
  RelOutPortB(CardNum, $11, $14);                     // software start, a scan at a time
  // RelOutPortB(CardNum, $11, $16);                  // timer start, a scan at a time
  // RelOutPortB(CardNum, $11, $15);                  // external start, a scan at a time

  PollTime.Enabled := True;
end;

procedure TMainForm.PollTimeTimer(Sender: TObject);
var
  Buf: String;
  T: Integer;
  Den, dT: Integer;
  ADData: Word;
  V: Extended;

begin
  RelOutPortB(CardNum, $1, $00);    // software start a conversion

  Buf := '';
  T := 0;
  Den := GetTickCount + 1000;
  repeat
    if (RelInPortB(CardNum, $12) and $20) <> 0 then begin
      ADData := RelInPort(CardNum, $0);
      V := ADData / $FFFF;
      if (JumperData and $01) <> 0 then V := V - 0.5;
      if (JumperData and $04) = 0 then V := V * 2;
      V := V * 10;
      V := Round(V * 1000) / 1000;

      Buf := Buf + 'Ch' + IntToHex(T, 1) + ': ' + FloatToStr(V) + 'V'#13#10;

      Inc(T);
      if T >= Channels then begin
        DataList.Items.Text := Buf;
        Exit;
      end;
    end;
    dT := GetTickCount;
    dT := dT - Den;
  until dT > 0;
end;

end.
