unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, ExtCtrls, StdCtrls, Registry;

type
  TMainForm = class(TForm)
    GroupBits: TRadioGroup;
    GroupOutput: TGroupBox;
    Value: TTrackBar;
    LOutput: TLabel;
    Label2: TLabel;
    GroupChannel: TRadioGroup;
    StatusBar1: TStatusBar;
    CardName: TLabel;
    AddressList: TComboBox;
    Memo1: TMemo;
    ExitButton: TButton;
    Initialize: TButton;
    Label3: TLabel;
    procedure GroupBitsClick(Sender: TObject);
    procedure GroupPolarityClick(Sender: TObject);
    procedure FormActivate(Sender: TObject);
    procedure UpdateDAC;
    function ConvertForOutput(counts:longword):longword;
    procedure ValueChange(Sender: TObject);
    procedure GroupRangeClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure ExitButtonClick(Sender: TObject);
    procedure InitializeClick(Sender: TObject);
    procedure AddressListChange(Sender: TObject);
  private
    { Private declarations }
    DriverRegistry:TRegistry;

  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

uses AIOWDM;

  //global variables for internal use
const
  bits:longword=12;
  Offset:double=5;
  invert:longint=1;
  CurVal:word=0;
  span:double=10.0;
  maxch:integer=16;

var
  RunFlag:Boolean;
  CardNum : byte;

{
  This function accepts a value of 0-65535 and returns
    the value scaled for the current DAC settings.
}
function TMainForm.ConvertForOutput(counts:longword):longword;
  var i:integer;
  CalV: Real;
  CalResult: LongWord;
begin
  result := trunc(counts / 65536.0*(1 shl bits)); //scale for 12 or 16 bits.

  //write to hardware here.
  if (GroupChannel.ItemIndex < maxch) then begin //the last item in the channel list is ALL
    RelOutPort(CardNum, $0C + (GroupChannel.ItemIndex*2), result);
  end
  else begin                               //"all channels" is selected, use simul mode
    for i := 0 to maxch-1 do
      RelOutPort(CardNum, $0C + (i*2), result);
  end;//else
end;

function IntToBin(input,bits:longword):string;
  var
    temp:string;
    i:word;
    f:double;
begin
//this for loop converts to binary
  temp:='';
  for i:=(bits-1) downto 0 do begin
    if (input AND (1 shl i))=0 then temp:=temp+'0' else temp:=temp+'1';
  end;//for;

//this conditional handles the xxxx for justification
  if bits=12 then temp:='xxxx'+temp;

  f:=((1 shl (bits+1)-1) AND input) * span / (1 shl bits) -  offset;

  temp:=temp+'  '+inttohex(input,bits div 4)+' '+floattostrf(f,ffFixed,6,6);
  result:=temp+' Volts';
end;


procedure TMainForm.UpdateDAC;
begin
  offset := 0;
  span := 10.0;
  LOutput.Caption := IntToBin(ConvertForOutput(CurVal),bits);
end;

procedure TMainForm.GroupBitsClick(Sender: TObject);
begin
end;//EndGroupBits

procedure TMainForm.GroupPolarityClick(Sender: TObject);
begin
end;//end GroupPolarity

procedure TMainForm.FormActivate(Sender: TObject);
begin
  memo1.lines.append('');
  memo1.lines.append('This sample outputs values to either or both DACs. If both are selected, simultaneous mode is used. '
                     +'This program assumes both DACs are configured for 0-10V output range.'
                     +' Check the source code and manual for information on how to detect the jumper settings programmatically.');
  Memo1.ScrollBars:=ssVertical;
end;

procedure TMainForm.ValueChange(Sender: TObject);
begin
  CurVal := value.position;
  UpdateDAC;
end;

procedure TMainForm.GroupRangeClick(Sender: TObject);
begin
    UpdateDAC;
end;

procedure TMainForm.FormCreate(Sender: TObject);
var
    num, i, j, n, t: Integer;
    DeviceID: Longword;
begin
    num:=0;
    n:=0;

    num := GetNumCards;
    if (num > 0) then
      for i := 0 to num-1 do
      begin
          QueryCardInfo(i, @DeviceID, nil, nil, nil);
          begin
              case (DeviceID) of
              $ECE9:begin
                  CardName.Caption:='LPCI-AIO16A Card';
                  AddressList.Items.Add('LPCI-AIO16A Card #'+IntToStr(n));
                  CardNum := 0; 
                  n := n + 1;
                  RunFlag := True;
                  maxch := 2;
                  CardName.Caption := 'LPCI-AIO16A Card';
                  AddressList.ItemIndex:=0;

                  GroupChannel.Items.Clear;
                  bits := 12;
                  value.LineSize := 16; //slider control

                  for j := 1 to maxch do
                    GroupChannel.Items.Append('Channel '+inttostr(j-1));
                  GroupChannel.Items.Append('All Channels');
                  GroupChannel.ItemIndex:=0;
                  end;
              end;{case}
          end;{with}
      end;{for}
end;

procedure TMainForm.ExitButtonClick(Sender: TObject);
begin
  close;
end;

procedure TMainForm.InitializeClick(Sender: TObject);
begin
    GroupOutput.visible:=True;
    GroupOutput.enabled:=True;
    RelOutPortB(CardNum, $10, 1); // put card's DACs in simultaneous mode
end;

procedure TMainForm.AddressListChange(Sender: TObject);
begin
  CardNum := AddressList.ItemIndex;
end;

end.
